;;; GNU Guix --- Functional package management for GNU
;;; Copyright © 2014 Mark H Weaver <mhw@netris.org>
;;; Copyright © 2014 Manolis Fragkiskos Ragkousis <manolis837@gmail.com>
;;; Copyright © 2016 Hartmut Goebel <h.goebel@crazy-compilers.com>
;;; Copyright © 2016, 2018, 2021 Ludovic Courtès <ludo@gnu.org>
;;; Copyright © 2016, 2019 Efraim Flashner <efraim@flashner.co.il>
;;; Copyright © 2017 Jonathan Brielmaier <jonathan.brielmaier@web.de>
;;; Copyright © 2017 Julien Lepiller <julien@lepiller.eu>
;;; Copyright © 2018–2021 Tobias Geerinckx-Rice <me@tobias.gr>
;;; Copyright © 2021 Ricardo Wurmus <rekado@elephly.net>
;;; Copyright © 2021 Mathieu Othacehe <othacehe@gnu.org>
;;; Copyright © 2022 Peter Polidoro <peter@polidoro.io>
;;;
;;; This file is part of GNU Guix.
;;;
;;; GNU Guix is free software; you can redistribute it and/or modify it
;;; under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 3 of the License, or (at
;;; your option) any later version.
;;;
;;; GNU Guix is distributed in the hope that it will be useful, but
;;; WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.

(define-module (speed-dreams)
  #:use-module (gnu packages)
  #:use-module (gnu packages base)
  #:use-module (gnu packages graphics)
  #:use-module (gnu packages gl)
  #:use-module (gnu packages xiph)
  #:use-module (gnu packages sdl)
  #:use-module (gnu packages audio)
  #:use-module (gnu packages networking)
  #:use-module (gnu packages image)
  #:use-module (gnu packages game-development)
  #:use-module (gnu packages curl)
  #:use-module (gnu packages pkg-config)
  #:use-module (gnu packages xml)
  #:use-module (gnu packages xorg)
  #:use-module (guix build-system cmake)
  #:use-module (guix build-system trivial)
  #:use-module (guix build-system gnu)
  #:use-module (guix build utils)
  #:use-module ((guix licenses) #:prefix license:)
  #:use-module (guix download)
  #:use-module (guix gexp)
  #:use-module (guix git-download)
  #:use-module (guix packages)
  #:use-module (guix utils))

(define-public plib-fpic
  (package
    (name "plib-fpic")
    (version "1.8.5")
    (source (origin
              (method url-fetch)
              (uri (string-append "http://plib.sourceforge.net/dist/"
                                  "plib-" version ".tar.gz"))
              (sha256
               (base32
                "0cha71mflpa10vh2l7ipyqk67dq2y0k5xbafwdks03fwdyzj4ns8"))
              (patches (search-patches "plib-CVE-2011-4620.patch"
                                       "plib-CVE-2012-4552.patch"))))
    (build-system gnu-build-system)
    (arguments
       (list
        #:make-flags
        #~(list
          "CFLAGS=-fPIC"
          "CXXFLAGS=-fPIC")))
    (inputs
     (list mesa libxi libxmu))
    (native-inputs
     (list pkg-config))
    (home-page "https://plib.sourceforge.net/")
    (synopsis "Suite of portable game libraries")
    (description "PLIB is a set of libraries that will permit programmers to
write games and other realtime interactive applications that are 100% portable
across a wide range of hardware and operating systems.  PLIB includes sound
effects, music, a complete 3D engine, font rendering, a simple Windowing
library, a game scripting language, a GUI, networking, 3D math library and a
collection of handy utility functions.  All are 100% portable across nearly
all modern computing platforms.  Each library component is fairly independent
of the others")
    (license license:lgpl2.0+)))


(define-public speed-dreams
  (package
    (name "speed-dreams")
    (version "2.3.0")
    (source
     (origin
       (method git-fetch)
       (uri (git-reference
             (url "https://forge.chalec.org/neox/speed-dreams")
             (commit version)))
       (file-name (git-file-name name version))
       (sha256
         (base32 "0w9l6lg4d20jiddkp1599l3hvy3y1745qv8pzb137kn8j2lz73c0"))))
    (build-system cmake-build-system)
    (arguments
     (list
      #:configure-flags
      #~(list
        "-DOPTION_UNLOAD_SSGGRAPH:BOOL=ON"
        "-DCMAKE_CXX_FLAGS=-march=native"
        "-DCMAKE_BUILD_TYPE=Release"
        "-DOPTION_OFFICIAL_ONLY:BOOL=ON")
      #:phases
      #~(modify-phases %standard-phases
         ;(add-after 'unpack 'make-git-checkout-writable
          ;(lambda* (#:key inputs #:allow-other-keys)
            ;(make-file-writable "CMakeLists.txt")))
         ;(add-after 'unpack 'apply-patches
          ;(lambda* (#:key inputs #:allow-other-keys)
            ;(invoke "patch" "--force" "-p1" 
                    ;"speed-dreams-add-desktop-entry.patch")))
        (delete 'validate-runpath)
        (delete 'check))))
    (native-inputs
      (list
        pkg-config))
    (inputs
      (list
        openscenegraph
        freeglut
        libvorbis
        sdl2
        sdl2-mixer
        openal
        enet
        expat
        ijg-libjpeg
        plib-fpic
        libpng
        curl))
    (license license:gpl2)
    (synopsis "SPEED")
    (description
      "SPEEEEEED.")
    (home-page "https://www.speed-dreams.net/en/")))


